@@ -8,10 +8,15 @@ sub new {
     my $class = shift;
     my $array = shift;
 
-    my $ptr = Algorithm::CP::IZ::alloc_var_array([map { $_->{_ptr } } @$array]);
+    my $ptr = Algorithm::CP::IZ::alloc_var_array([map { $$_ } @$array]);
     bless \$ptr, $class;
 }
 
+sub ptr {
+    my $self = shift;
+    return $$self;
+}
+
 sub DESTROY {
     my $self = shift;
     Algorithm::CP::IZ::free_array($$self);
